/* 
 * "ESCOT.H"
 * 
 * The Escotia Playstation Library 
 *
 * Functions to make programming a chore not a pleasure
 *
 * Author:	ScoTT Campbell
 * Date:	11/8/98
 *
*/

#ifndef __ESCOTHEADER
#define __ESCOTHEADER


#define MAX_OT_LENGTH		(14)			// Maximum length of any ordering table

#define WORLD_OT_LENGTH		(12)				// Length of the global worldOT[] 's

GsOT worldOT[2];							// Global world OT headers
GsOT_TAG OTElements[2][1<<WORLD_OT_LENGTH];	// Global world OT's


#define MAX_PRIMITIVES (16000)				// Number of primitives to be displayed


PACKET packetArray[2][MAX_PRIMITIVES * 24]; // Space for drawing commands



void InitWorldOTs();
/* Initialises the two main ordering tables used for double buffering								*/ 
/* Pre:	 worldOT is an GsOT array of two elements, OTElements is a 2-d GsOT_TAG array whose second	*/
/*		 index is at least OT_LENGTH in size, packetArray must be a 2-d array and OT_LENGTH must be	*/
/*		 defined.																					*/
/* Post: worldOT is an initialised 2-d array ready to hold drawing commands							*/			


GsOT* CreateOT(unsigned char length);
/* Creates a new ordering table with 1<<length elements												*/
/* Pre:	 length must not be greater than OT_LENGTH													*/
/* Post: pointer that is returned points to head of new OT; otherwise NULL							*/
																									


void DestroyOT(GsOT* otPtr);
/* Destroys the OT pointed to by otPtr																*/
/* Pre:  otPtr points to the header of an initialised OT											*/
/* Post: The memory used for the OT is freed, and otPtr	is set to NULL								*/


#endif				